]> git.tuebingen.mpg.de Git - paraslash.git/blobdiff - sched.c
Kill unused error code WRITE_OK.
[paraslash.git] / sched.c
diff --git a/sched.c b/sched.c
index a7660f5972c9f678b6f3a19b7b4398a1e43ae24b..42c5f14215df5e3f28ff91c11469b5dacf9f2e4a 100644 (file)
--- a/sched.c
+++ b/sched.c
@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2006-2007 Andre Noll <maan@systemlinux.org>
+ * Copyright (C) 2006-2008 Andre Noll <maan@systemlinux.org>
  *
  * Licensed under the GPL v2. For licencing details see COPYING.
  */
@@ -68,7 +68,7 @@ static void sched_post_select(struct sched *s)
  *
  * \sa task, now.
  */
-int sched(struct sched *s)
+int schedule(struct sched *s)
 {
        if (!initialized)
                return -E_NOT_INITIALIZED;
@@ -148,7 +148,7 @@ void unregister_task(struct task *t)
 /**
  * unregister all tasks
  *
* This will cause \a sched() to return immediately because both the
  * \a pre_select_list and the \a post_select_list are empty.
  */
 void sched_shutdown(void)
@@ -148,7 +148,7 @@ void unregister_task(struct task *t)
  * unregister all tasks
  *
- * This will cause \a sched() to return immediately because both the
+ * This will cause \a schedule() to return immediately because both the
  * \a pre_select_list and the \a post_select_list are empty.
  */